from fire import Fire


def tv_json():
    from tvpy.tv_json import tv_json
    Fire(tv_json)


def tv_down():
    from tvpy.tv_down import tv_down
    Fire(tv_down)


def tv_subs():
    from tvpy.tv_subs import tv_subs
    Fire(tv_subs)


def tv_renm():
    from tvpy.tv_renm import tv_renm
    Fire(tv_renm)


def tv_klyn():
    from tvpy.tv_klyn import tv_klyn
    Fire(tv_klyn)


def tv_info():
    from tvpy.tv_info import tv_info
    Fire(tv_info)


def tv_html():
    from tvpy.tv_html import tv_html
    Fire(tv_html)


def tvpy():
    from tvpy.tvpy import tvpy
    Fire(tvpy)
